from fastapi import FastAPI
from fastapi.middleware.cors import CORSMiddleware
import uvicorn
from app.api.items import router as items_router
from app.db.base import engine, Base

Base.metadata.create_all(bind=engine)

app = FastAPI(
    title="REST API Service",
    description="A FastAPI REST API service",
    version="1.0.0",
    openapi_url="/openapi.json",
)

app.add_middleware(
    CORSMiddleware,
    allow_origins=["*"],
    allow_credentials=True,
    allow_methods=["*"],
    allow_headers=["*"],
)

app.include_router(items_router, prefix="/api/v1", tags=["items"])


@app.get("/")
async def root():
    return {
        "title": "REST API Service",
        "documentation": "/docs",
        "health_check": "/health",
    }


@app.get("/health")
async def health_check():
    return {"status": "healthy", "service": "REST API Service"}


if __name__ == "__main__":
    uvicorn.run(app, host="0.0.0.0", port=8000)
